import { system, world, EntityDamageCause } from "@minecraft/server";


const dimensions = ["overworld", "nether", "the_end"];

system.runInterval(() => {
    for (const dimName of dimensions) {
        const dimension = world.getDimension(dimName);
        if (!dimension) continue;

        
        const vacasSaturno = dimension.getEntities({ type: "darkxie:vaca_saturno_saturnita" });

        for (const vaca of vacasSaturno) {
            const vacaLoc = vaca.location;
            if (!vacaLoc) continue;

            
            const nearbyEntities = dimension.getEntities({
                location: vacaLoc,
                maxDistance: 10,
                excludeTypes: ["darkxie:vaca_saturno_saturnita"]
            });

            for (const entity of nearbyEntities) {
                const entityLoc = entity.location;
                if (!entityLoc) continue;

                const dx = entityLoc.x - vacaLoc.x;
                const dy = entityLoc.y - vacaLoc.y;
                const dz = entityLoc.z - vacaLoc.z;
                const distanceSq = dx * dx + dy * dy + dz * dz;

                
                if (distanceSq < 8) {
                    try {
                        entity.applyDamage(2, { cause: EntityDamageCause.entityAttack });
                    } catch (e) {
                        console.warn(`[${dimName}] No se pudo dañar a ${entity.typeId}: ${e}`);
                    }
                } else {
                    
                    const angle = Math.random() * 2 * Math.PI;
                    const radius = 3 + Math.random() * 5; 
                    const offsetX = Math.cos(angle) * radius;
                    const offsetZ = Math.sin(angle) * radius;

                    const targetPos = {
                        x: vacaLoc.x + offsetX,
                        y: vacaLoc.y,
                        z: vacaLoc.z + offsetZ
                    };

                    try {
                        entity.teleport(targetPos, { facingLocation: vacaLoc });
                    } catch (e) {
                        console.warn(`[${dimName}] No se pudo mover a ${entity.typeId}: ${e}`);
                    }
                }
            }
        }
    }
}, 40);

// by iDarkxie - BETA